function val = volume_(O)
% volume_ - returns the volume of a full-dimensional space
%
% Syntax:
%    val = volume_(O)
%
% Inputs:
%    O - emptySet object
%
% Outputs:
%    val - volume
%
% Example: 
%    O = emptySet(2);
%    val = volume(O);
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: contSet/volume

% Authors:       Mark Wetzlinger
% Written:       22-March-2023
% Last update:   05-April-2023 (rename volume_)
% Last revision: ---

% ------------------------------ BEGIN CODE -------------------------------

% volume always zero
val = 0;

% ------------------------------ END OF CODE ------------------------------
